LockedXmlTraits
===============

.. currentmodule:: wwt_data_formats

.. autoclass:: LockedXmlTraits
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LockedXmlTraits.apply_to_xml
      ~LockedXmlTraits.from_file
      ~LockedXmlTraits.from_text
      ~LockedXmlTraits.from_url
      ~LockedXmlTraits.from_xml
      ~LockedXmlTraits.to_xml
      ~LockedXmlTraits.to_xml_string
      ~LockedXmlTraits.write_xml

   .. rubric:: Methods Documentation

   .. automethod:: apply_to_xml
   .. automethod:: from_file
   .. automethod:: from_text
   .. automethod:: from_url
   .. automethod:: from_xml
   .. automethod:: to_xml
   .. automethod:: to_xml_string
   .. automethod:: write_xml
